comaps_scale method

void comaps_scale(
  1. double factor,
  2. double pixelX,
  3. double pixelY,
  4. int animated,
)

Scale (zoom) the map by a factor, centered on a specific pixel point. factor: Zoom factor (>1 zooms in, <1 zooms out). Use exp(scrollDelta) for smooth zooming. pixelX, pixelY: Screen coordinates to zoom towards (in physical pixels) animated: Whether to animate the zoom transition This is the preferred method for scroll wheel zoom on desktop platforms.

Implementation

void comaps_scale(
  double factor,
  double pixelX,
  double pixelY,
  int animated,
) {
  return _comaps_scale(factor, pixelX, pixelY, animated);
}