DeleteResult class

Result of a map deletion operation.

Constructors

DeleteResult({required String regionName, required bool success, String? error, int? deletedBytes})
const

Properties

deletedBytes → int?
Bytes freed by deletion (if successful).
final
error → String?
Error message if deletion failed.
final
hashCode → int
The hash code for this object.
no setterinherited
regionName → String
Region name that was attempted to delete.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
Whether the deletion was successful.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited