isOrphaned property
bool
get
isOrphaned
True if metadata exists but file is missing (orphaned).
Implementation
bool get isOrphaned => hasMetadata && !exists;
True if metadata exists but file is missing (orphaned).
bool get isOrphaned => hasMetadata && !exists;