CountriesData class
Parsed countries.txt data (JSON format from CoMaps CDN)
Constructors
-
CountriesData({required int version, required List<
MwmRegion> regions}) -
CountriesData.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
allRegions
→ List<
MwmRegion> -
Get all regions flattened (including subregions)
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
regions
→ List<
MwmRegion> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalSizeBytes → int
-
Get total size of all regions
no setter
- version → int
-
final
Methods
-
findRegion(
String id) → MwmRegion? - Find a region by ID
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited