MirrorStatus class
Result of checking a mirror's availability
Constructors
- MirrorStatus({required MirrorConfig mirror, required bool isAccessible, int? latencyMs, String? latestSnapshot, String? error, bool isFromMetaserver = false})
-
const
Properties
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAccessible → bool
-
final
- isFromMetaserver → bool
-
final
- isOperational → bool
-
no setter
- latencyMs → int?
-
final
- latestSnapshot → String?
-
final
- mirror → MirrorConfig
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited