Mirror class

Represents a mirror server hosting MWM files.

Extends MirrorConfig with runtime state (latency, availability).

Constructors

Mirror({required String name, required String baseUrl, int? latencyMs, bool isAvailable = true})
Mirror.fromConfig(MirrorConfig config)
Create from MirrorConfig
factory

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
isAvailable bool
getter/setter pair
latencyMs int?
getter/setter pair
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toConfig() MirrorConfig
Convert to MirrorConfig
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited