MirrorDiscoveryResult class

Result of runtime mirror discovery.

Contains the mirror, its latest available snapshot, and any error.

Constructors

MirrorDiscoveryResult({required Mirror mirror, Snapshot? latestSnapshot, String? error})

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
isOperational bool
Whether this mirror is operational (accessible with a valid snapshot)
no setter
latestSnapshot Snapshot?
final
mirror Mirror
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusText String
Human-readable status string
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited